# redrover-api
Access Red Rover data via this REST API for Organizations that have granted you access.

# Authentication
The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.

This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.

Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.

# API Information
## Api Key
Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.

You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.

## Identifier
Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pike character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pike character.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.10
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/edustaff/redrover-api.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/edustaff/redrover-api.git`)

Then import the package:
```python
import redrover_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import redrover_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import redrover_api
from pprint import pprint
from redrover_api.apis.tags import absence_api
from redrover_api.model.absence_create_request import AbsenceCreateRequest
from redrover_api.model.absence_response import AbsenceResponse
from redrover_api.model.absence_update_request import AbsenceUpdateRequest
from redrover_api.model.bad_request_result import BadRequestResult
from redrover_api.model.not_found_result import NotFoundResult
from redrover_api.model.ok_result import OkResult
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = redrover_api.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basic
configuration = redrover_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with redrover_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = absence_api.AbsenceApi(api_client)
    org_id = 1 # int | The Red Rover Id of the Organization
absence_create_request = AbsenceCreateRequest(
        validate_only=False,
        external_id="external_id_example",
        employee=Int32LocatorRequest(
            id=1,
            external_id="external_id_example",
        ),
        notes_to_approver="notes_to_approver_example",
        admin_only_notes="admin_only_notes_example",
        details=[
            AbsenceDetailCreateRequest(
                date="1970-01-01T00:00:00.00Z",
                day_part=DayPartEnum(1),
                description="description_example",
                start_time="1970-01-01T00:00:00.00Z",
                end_time="1970-01-01T00:00:00.00Z",
                reasons=[
                    AbsenceReasonUsageCreateRequest(
                        usage="usage_example",
                        daily_amount=3.14,
                        hourly_amount=3.14,
                        id=1,
                        external_id="external_id_example",
                    )
                ],
            )
        ],
        start_date="1970-01-01T00:00:00.00Z",
        end_date="1970-01-01T00:00:00.00Z",
        vacancies=[
            AbsenceVacancyRequest(
                position=Int32LocatorRequest(),
                details=[
                    AbsenceVacancyDetailRequest(
                        location=Int32LocatorRequest(),
                        needs_replacement=True,
                        date="1970-01-01T00:00:00.00Z",
                        day_part_id=DayPartEnum(1),
                        start_time="start_time_example",
                        end_time="end_time_example",
                        accounting_code_allocations=[
                            VacancyAccountingCodeAllocationRequest(
                                accounting_code=Int32LocatorRequest(),
                                allocation=3.14,
                            )
                        ],
                        pay_code=Int32LocatorRequest(),
                        replacement_employee=Int32LocatorRequest(),
                    )
                ],
                notes_to_replacement="notes_to_replacement_example",
                allow_sub_to_accept_part=True,
                external_id="external_id_example",
                pay_code=Int32LocatorRequest(),
                hold_for_manual_fill=True,
                administrator_comments="administrator_comments_example",
            )
        ],
    ) # AbsenceCreateRequest | The details of the Absence

    try:
        # Create new Absence
        api_response = api_instance.create_absence(org_idabsence_create_request)
        pprint(api_response)
    except redrover_api.ApiException as e:
        print("Exception when calling AbsenceApi->create_absence: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AbsenceApi* | [**create_absence**](docs/apis/tags/AbsenceApi.md#create_absence) | **post** /api/v1/{orgId}/Absence | Create new Absence
*AbsenceApi* | [**delete_absence**](docs/apis/tags/AbsenceApi.md#delete_absence) | **delete** /api/v1/{orgId}/Absence/{identifier} | Delete an Absence
*AbsenceApi* | [**get_absence**](docs/apis/tags/AbsenceApi.md#get_absence) | **get** /api/v1/{orgId}/Absence/{identifier} | Get Absence
*AbsenceApi* | [**get_absences**](docs/apis/tags/AbsenceApi.md#get_absences) | **get** /api/v1/{orgId}/Absence | Get list of Absences
*AbsenceApi* | [**update_absence**](docs/apis/tags/AbsenceApi.md#update_absence) | **put** /api/v1/{orgId}/Absence/{identifier} | Update existing Absence
*AbsenceReasonApi* | [**get_absence_reason**](docs/apis/tags/AbsenceReasonApi.md#get_absence_reason) | **get** /api/v1/{orgId}/AbsenceReason/{identifier} | Get Absence Reason
*AbsenceReasonApi* | [**get_absence_reasons**](docs/apis/tags/AbsenceReasonApi.md#get_absence_reasons) | **get** /api/v1/{orgId}/AbsenceReason | Get list of Absence Reasons
*AbsenceReasonBalanceApi* | [**create_absence_reason_balance**](docs/apis/tags/AbsenceReasonBalanceApi.md#create_absence_reason_balance) | **post** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances | Create Absence Reason Balance
*AbsenceReasonBalanceApi* | [**delete_absence_reason_balance**](docs/apis/tags/AbsenceReasonBalanceApi.md#delete_absence_reason_balance) | **delete** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Delete Absence Reason Balance
*AbsenceReasonBalanceApi* | [**get_absence_reason_balance**](docs/apis/tags/AbsenceReasonBalanceApi.md#get_absence_reason_balance) | **get** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Get Absence Reason Balance
*AbsenceReasonBalanceApi* | [**get_absence_reason_balances**](docs/apis/tags/AbsenceReasonBalanceApi.md#get_absence_reason_balances) | **get** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances | Get Absence Reason Balances
*AbsenceReasonBalanceApi* | [**update_absence_reason_balance**](docs/apis/tags/AbsenceReasonBalanceApi.md#update_absence_reason_balance) | **put** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Update Absence Reason Balance
*AssignmentApi* | [**get_assignment**](docs/apis/tags/AssignmentApi.md#get_assignment) | **get** /api/v1/{orgId}/Assignment/{identifier} | Get Assignment
*ConnectionApi* | [**download_report**](docs/apis/tags/ConnectionApi.md#download_report) | **get** /api/v1/{orgId}/Connection/{id}/download | Download Report
*ConnectionApi* | [**download_report_0**](docs/apis/tags/ConnectionApi.md#download_report_0) | **post** /api/v1/{orgId}/Connection/{id}/download | Download Report
*ConnectionApi* | [**post_report_data**](docs/apis/tags/ConnectionApi.md#post_report_data) | **post** /api/v1/{orgId}/Connection/{id}/data | Posts Report
*ConnectionApi* | [**run_report**](docs/apis/tags/ConnectionApi.md#run_report) | **post** /api/v1/{orgId}/Connection/{id}/run | Run Report
*OrganizationApi* | [**get_current_school_years**](docs/apis/tags/OrganizationApi.md#get_current_school_years) | **get** /api/v1/Organization/{id}/schoolYear/current | Get current School Year
*OrganizationApi* | [**get_organization**](docs/apis/tags/OrganizationApi.md#get_organization) | **get** /api/v1/Organization/{id} | Get Organization
*OrganizationApi* | [**get_organizations**](docs/apis/tags/OrganizationApi.md#get_organizations) | **get** /api/v1/Organization | Get Organizations
*OrganizationApi* | [**get_school_years**](docs/apis/tags/OrganizationApi.md#get_school_years) | **get** /api/v1/Organization/{id}/schoolYear | Get School Years
*ReferenceDataApi* | [**gets_attributes**](docs/apis/tags/ReferenceDataApi.md#gets_attributes) | **get** /api/v1/{orgId}/ReferenceData/attribute | Get Attributes
*ReferenceDataApi* | [**gets_attributes_0**](docs/apis/tags/ReferenceDataApi.md#gets_attributes_0) | **post** /api/v1/{orgId}/ReferenceData/attribute | Create attribute
*UserApi* | [**create_admin**](docs/apis/tags/UserApi.md#create_admin) | **post** /api/v1/{orgId}/User/administrator | Creates Administrator
*UserApi* | [**create_employee**](docs/apis/tags/UserApi.md#create_employee) | **post** /api/v1/{orgId}/User/employee | Creates Employee
*UserApi* | [**create_substitute**](docs/apis/tags/UserApi.md#create_substitute) | **post** /api/v1/{orgId}/User/substitute | Creates Substitute
*UserApi* | [**delete_user**](docs/apis/tags/UserApi.md#delete_user) | **delete** /api/v1/{orgId}/User/{identifier} | Deletes User
*UserApi* | [**delete_user_role**](docs/apis/tags/UserApi.md#delete_user_role) | **delete** /api/v1/{orgId}/User/{identifier}/{role} | Deletes User&#x27;s Role
*UserApi* | [**get_admin**](docs/apis/tags/UserApi.md#get_admin) | **get** /api/v1/{orgId}/User/administrator/{identifier} | Gets Administrator
*UserApi* | [**get_employee**](docs/apis/tags/UserApi.md#get_employee) | **get** /api/v1/{orgId}/User/employee/{identifier} | Gets Employee
*UserApi* | [**get_substitute**](docs/apis/tags/UserApi.md#get_substitute) | **get** /api/v1/{orgId}/User/substitute/{identifier} | Get Substitute by Id
*UserApi* | [**get_substitutes**](docs/apis/tags/UserApi.md#get_substitutes) | **get** /api/v1/{orgId}/User/substitute | Query for Substitutes
*UserApi* | [**update_admin**](docs/apis/tags/UserApi.md#update_admin) | **put** /api/v1/{orgId}/User/administrator/{identifier} | Updates Administrator
*UserApi* | [**update_employee**](docs/apis/tags/UserApi.md#update_employee) | **put** /api/v1/{orgId}/User/employee/{identifier} | Updates Employee
*UserApi* | [**update_substitute**](docs/apis/tags/UserApi.md#update_substitute) | **put** /api/v1/{orgId}/User/substitute/{identifier} | Updates Substitute
*VacancyApi* | [**delete_vacancy**](docs/apis/tags/VacancyApi.md#delete_vacancy) | **delete** /api/v1/{orgId}/Vacancy/{identifier} | Delete Vacancy By Id
*VacancyApi* | [**get_vacancy**](docs/apis/tags/VacancyApi.md#get_vacancy) | **get** /api/v1/{orgId}/Vacancy/{identifier} | Get Vacancy By Id
*VacancyApi* | [**get_vacancy_details**](docs/apis/tags/VacancyApi.md#get_vacancy_details) | **get** /api/v1/{orgId}/Vacancy/vacancyDetails |  Query Vacancy Details
*VacancyApi* | [**post_vacancy**](docs/apis/tags/VacancyApi.md#post_vacancy) | **post** /api/v1/{orgId}/Vacancy | Create a Vacancy
*WebhooksApi* | [**create_webhook**](docs/apis/tags/WebhooksApi.md#create_webhook) | **post** /api/v1/Webhooks | Create Webhook.
*WebhooksApi* | [**delete_webhook**](docs/apis/tags/WebhooksApi.md#delete_webhook) | **delete** /api/v1/Webhooks/{id} | Delete Webhook
*WebhooksApi* | [**get_webhook**](docs/apis/tags/WebhooksApi.md#get_webhook) | **get** /api/v1/Webhooks | Get Webhooks
*WebhooksApi* | [**get_webhook_0**](docs/apis/tags/WebhooksApi.md#get_webhook_0) | **get** /api/v1/Webhooks/{identifier} | Get Webhook
*WebhooksApi* | [**put_webhook_uri**](docs/apis/tags/WebhooksApi.md#put_webhook_uri) | **put** /api/v1/Webhooks/{id} | Update Webhook

## Documentation For Models

 - [AbsenceCreateRequest](docs/models/AbsenceCreateRequest.md)
 - [AbsenceDetailCreateRequest](docs/models/AbsenceDetailCreateRequest.md)
 - [AbsenceDetailResponse](docs/models/AbsenceDetailResponse.md)
 - [AbsenceReasonBalanceCreateRequest](docs/models/AbsenceReasonBalanceCreateRequest.md)
 - [AbsenceReasonBalanceResponse](docs/models/AbsenceReasonBalanceResponse.md)
 - [AbsenceReasonBalanceUpdateRequest](docs/models/AbsenceReasonBalanceUpdateRequest.md)
 - [AbsenceReasonCategoryResponse](docs/models/AbsenceReasonCategoryResponse.md)
 - [AbsenceReasonResponse](docs/models/AbsenceReasonResponse.md)
 - [AbsenceReasonTrackingTypeEnum](docs/models/AbsenceReasonTrackingTypeEnum.md)
 - [AbsenceReasonUsageCreateRequest](docs/models/AbsenceReasonUsageCreateRequest.md)
 - [AbsenceReasonUsageResponse](docs/models/AbsenceReasonUsageResponse.md)
 - [AbsenceResponse](docs/models/AbsenceResponse.md)
 - [AbsenceUpdateRequest](docs/models/AbsenceUpdateRequest.md)
 - [AbsenceVacancyDetailRequest](docs/models/AbsenceVacancyDetailRequest.md)
 - [AbsenceVacancyRequest](docs/models/AbsenceVacancyRequest.md)
 - [AccessControlRequest](docs/models/AccessControlRequest.md)
 - [AccessControlResponse](docs/models/AccessControlResponse.md)
 - [AccountingCodeAllocationRequest](docs/models/AccountingCodeAllocationRequest.md)
 - [AccountingCodeAllocationResponse](docs/models/AccountingCodeAllocationResponse.md)
 - [AccountingCodeResponse](docs/models/AccountingCodeResponse.md)
 - [AdministratorRequest](docs/models/AdministratorRequest.md)
 - [AdministratorResponse](docs/models/AdministratorResponse.md)
 - [ApprovalStatusEnum](docs/models/ApprovalStatusEnum.md)
 - [AssignmentResponse](docs/models/AssignmentResponse.md)
 - [AttributeRequest](docs/models/AttributeRequest.md)
 - [AttributeResponse](docs/models/AttributeResponse.md)
 - [AuthenticationProperties](docs/models/AuthenticationProperties.md)
 - [BadRequestResult](docs/models/BadRequestResult.md)
 - [ContractResponse](docs/models/ContractResponse.md)
 - [CountryEnum](docs/models/CountryEnum.md)
 - [DayOfWeek](docs/models/DayOfWeek.md)
 - [DayPartEnum](docs/models/DayPartEnum.md)
 - [EmployeeRequest](docs/models/EmployeeRequest.md)
 - [EmployeeResponse](docs/models/EmployeeResponse.md)
 - [FileFormat](docs/models/FileFormat.md)
 - [FillStatusEnum](docs/models/FillStatusEnum.md)
 - [ForbidResult](docs/models/ForbidResult.md)
 - [Int32IdNameClass](docs/models/Int32IdNameClass.md)
 - [Int32LocatorRequest](docs/models/Int32LocatorRequest.md)
 - [Int32LocatorResponse](docs/models/Int32LocatorResponse.md)
 - [NeedsReplacementEnum](docs/models/NeedsReplacementEnum.md)
 - [NotFoundResult](docs/models/NotFoundResult.md)
 - [OkObjectResult](docs/models/OkObjectResult.md)
 - [OkResult](docs/models/OkResult.md)
 - [OrgUserEmployeeResponse](docs/models/OrgUserEmployeeResponse.md)
 - [OrganizationResponse](docs/models/OrganizationResponse.md)
 - [PayCodeResponse](docs/models/PayCodeResponse.md)
 - [PositionJobRequest](docs/models/PositionJobRequest.md)
 - [PositionRequest](docs/models/PositionRequest.md)
 - [PositionResponse](docs/models/PositionResponse.md)
 - [PositionScheduleCustomVariantRequest](docs/models/PositionScheduleCustomVariantRequest.md)
 - [PositionScheduleItemRequest](docs/models/PositionScheduleItemRequest.md)
 - [PositionScheduleModeEnum](docs/models/PositionScheduleModeEnum.md)
 - [PositionScheduleRequest](docs/models/PositionScheduleRequest.md)
 - [Reason](docs/models/Reason.md)
 - [SchoolYearResponse](docs/models/SchoolYearResponse.md)
 - [SimpleAbsenceDetail](docs/models/SimpleAbsenceDetail.md)
 - [SimplePerson](docs/models/SimplePerson.md)
 - [SimplePosition](docs/models/SimplePosition.md)
 - [StateEnum](docs/models/StateEnum.md)
 - [SubstituteAttributeRequest](docs/models/SubstituteAttributeRequest.md)
 - [SubstituteAttributeResponse](docs/models/SubstituteAttributeResponse.md)
 - [SubstitutePreferencesRequest](docs/models/SubstitutePreferencesRequest.md)
 - [SubstituteRelatedOrgRequest](docs/models/SubstituteRelatedOrgRequest.md)
 - [SubstituteRequest](docs/models/SubstituteRequest.md)
 - [SubstituteResponse](docs/models/SubstituteResponse.md)
 - [TimeOffBalanceRequest](docs/models/TimeOffBalanceRequest.md)
 - [UserRoles](docs/models/UserRoles.md)
 - [VacancyAccountingCodeAllocationRequest](docs/models/VacancyAccountingCodeAllocationRequest.md)
 - [VacancyCreateRequest](docs/models/VacancyCreateRequest.md)
 - [VacancyDetailCreateRequest](docs/models/VacancyDetailCreateRequest.md)
 - [VacancyDetailResponse](docs/models/VacancyDetailResponse.md)
 - [VacancyDetailSearchResponse](docs/models/VacancyDetailSearchResponse.md)
 - [VacancyResponse](docs/models/VacancyResponse.md)
 - [WebhookCreateRequest](docs/models/WebhookCreateRequest.md)
 - [WebhookResponse](docs/models/WebhookResponse.md)
 - [WebhookUpdateRequest](docs/models/WebhookUpdateRequest.md)

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="basic"></a>
### basic

- **Type**: HTTP basic authentication


## Author

dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com
dev@redroverk12.com

## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in redrover_api.apis and redrover_api.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from redrover_api.apis.default_api import DefaultApi`
- `from redrover_api.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import redrover_api
from redrover_api.apis import *
from redrover_api.models import *
```
